Version command

### Navigation

- index
- next |
- previous |
- fantastico 0.5.0-b126 documentation »
- Fantastico features »
- SDK »

# Version command

This command tells you what is the current installed version of Fantastico SDK.

class `fantastico.sdk.commands.command_version.` `SdkCommandVersion`(argv, cmd_factory, version_reader=<module 'fantastico' from '/mnt/jenkins_ebs/continous_integration/fantastico_doc_workspace/fantastico/__init__.py'>)

  This class provides the command for finding out installed version of Fantastico SDK. The value is defined in fantastico root module code.

      # display help information for version command in sdk context
      fsdk version --help

      # display the current sdk version
      fsdk version

  `exec`(print_fn=<built-in function print>)

    This method prints the current fantastico framework version.

  `get_help`()

    This method returns the friendly help message describing the method.